==> geant4.10.03.p03.tar.gz: geant4.10.03.p03/examples/.doxygen/Doxymodules_parameterisations.h <==
// $Id: Doxymodules_parameterisations.h 94561 2015-11-24 09:17:12Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_parameterisations.h
/// \brief The page that defines the extended/parameterisations examples modules 


/** @defgroup extended_parameterisations parameterisations
 *  Extended examples parameterisations classes
 *  @{
 */

/** @defgroup extended_parameterisations_Par01 Par01
 *  parameterisations example Par01
 *  @{
 */

class Par01ActionInitialization {};
class Par01CalorimeterHit {};
class Par01CalorimeterSD {};
class Par01DetectorConstruction {};
class Par01EMShowerModel {};
class Par01EnergySpot {};
class Par01ParallelWorldForPion {};
class Par01PhysicsList {};
class Par01PiModel {};
class Par01PionShowerModel {};
class Par01PrimaryGeneratorAction {};


/** @} */

/** @defgroup extended_parameterisations_Par02 Par02
 *  parameterisations example Par02
 *  @{
 */

class Par02ActionInitialization {};
class Par02DetectorConstruction {};
class Par02DetectorParametrisation {};
class Par02EventAction {};
class Par02EventInformation {};
class Par02FastSimModelEMCal {};
class Par02FastSimModelHCal {};
class Par02FastSimModelTracker {};
class Par02Output {};
class Par02PhysicsList {};
class Par02PrimaryGeneratorAction {};
class Par02PrimaryParticleInformation {};
class Par02RunAction {};
class Par02Smearer {};
class Par02TrackingAction {};

/** @} */

/** @defgroup extended_parameterisations_gflash gflash
 *  parameterisations example gflash
 *  @{
 */

  class ExGflashActionInitialization {};
  class ExGflashDetectorConstruction {};
  class ExGflashEventAction {};
  class ExGflashHit {};
  class ExGflashHitsCollection {};
  class ExGflashPhysicsList {};
  class ExGflashPrimaryGeneratorAction {};
  class ExGflashRunAction {};
  class ExGflashSensitiveDetector {};

/** @} */

/** @} */

==> geant4.10.04.tar.gz: geant4.10.04/examples/.doxygen/Doxymodules_parameterisations.h <==
// $Id: Doxymodules_parameterisations.h 104750 2017-06-15 08:47:26Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_parameterisations.h
/// \brief The page that defines the extended/parameterisations examples modules 


/** @defgroup extended_parameterisations parameterisations
 *  Extended examples parameterisations classes
 *  @{
 */

/** @defgroup extended_parameterisations_Par01 Par01
 *  parameterisations example Par01
 *  @{
 */

class Par01ActionInitialization {};
class Par01CalorimeterHit {};
class Par01CalorimeterSD {};
class Par01DetectorConstruction {};
class Par01EMShowerModel {};
class Par01EnergySpot {};
class Par01ParallelWorldForPion {};
class Par01PiModel {};
class Par01PionShowerModel {};
class Par01PrimaryGeneratorAction {};


/** @} */

/** @defgroup extended_parameterisations_Par02 Par02
 *  parameterisations example Par02
 *  @{
 */

class Par02ActionInitialization {};
class Par02DetectorConstruction {};
class Par02DetectorParametrisation {};
class Par02EventAction {};
class Par02EventInformation {};
class Par02FastSimModelEMCal {};
class Par02FastSimModelHCal {};
class Par02FastSimModelTracker {};
class Par02Output {};
class Par02PhysicsList {};
class Par02PrimaryGeneratorAction {};
class Par02PrimaryParticleInformation {};
class Par02RunAction {};
class Par02Smearer {};
class Par02TrackingAction {};

/** @} */

/** @defgroup extended_parameterisations_gflash gflash
 *  parameterisations example gflash
 *  @{
 */

  class ExGflashActionInitialization {};
  class ExGflashDetectorConstruction {};
  class ExGflashEventAction {};
  class ExGflashHit {};
  class ExGflashHitsCollection {};
  class ExGflashPhysics {};
  class ExGflashPrimaryGeneratorAction {};
  class ExGflashRunAction {};
  class ExGflashSensitiveDetector {};

/** @} */

/** @} */
